FontSize class

Inheritance
Available extensions

Constructors

FontSize(double size, [Unit unit = Unit.px])

Properties

emValue → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit ↔ Unit
getter/setter pairinherited
value ↔ double
getter/setter pairinherited

Methods

normalize(double emValue) → void

Available on Dimension, provided by the Normalize extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

large → FontSize
final
larger → FontSize
final
medium → FontSize
final
small → FontSize
final
smaller → FontSize
final
xLarge → FontSize
final
xSmall → FontSize
final
xxLarge → FontSize
final
xxSmall → FontSize
final

Static Methods

inherit(FontSize? parent, FontSize? child) → FontSize?